@@ -123,10 +123,11 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
         An :py:class:`~pyhive.exc.Error` (or subclass) exception is raised if the previous call to
         :py:meth:`execute` did not produce any result set or no call was issued yet.
         """
-        _logger.info("Commons - fetch many")
+        _logger.info("Commons - fetch many.... size - {}".format(size))
         if size is None:
             size = self.arraysize
-        return list(islice(iter(self.fetchone, None), size))
+        # return list(islice(iter(self.fetchone, None), size))
+        return list(iter(self.fetchone, None))
 
     def fetchall(self):
         """Fetch all (remaining) rows of a query result, returning them as a sequence of sequences
